/*
io_x9sd.c

Hardware routines for interfacing with SD cards on a Ninjapass X9

Copyright (C) 2007 by CJ Bell
siegebell@gmail.com


This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Library General Public
License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Library General Public License for more details.

You should have received a copy of the GNU Library General Public
License along with this library; if not, write to the
Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
Boston, MA  02110-1301, USA.
*/

#include "disc_io.h"

#ifdef NDS

#include <nds.h>
#include "io_sd_card.h"
#include "io_x9_card.h"

uint32 relativeCardAddress;


bool _X9SD_isInserted(void)
{
	return true;
}

bool _X9SD_clearStatus(void)
{
	return true;
}

bool _X9SD_shutdown(void)
{
	return true;
}

bool _X9SD_startup(void)
{
    cardIO_3(0);
    cardIO_4(0);
    return true;
} 


bool _X9SD_writeSectors (uint32 sector, uint32 sectorCount, const void* buffer)
{
    const uint32 blockLength = 512;
    while(sectorCount > 0)
    {
        SDWriteSingleBlock(sector*blockLength, buffer);
 
        buffer+= blockLength;
        --sectorCount;
        ++sector;
    }

    return true;
}

bool _X9SD_readSectors (uint32 sector, uint32 sectorCount, void* buffer)
{    

    const uint32 blockLength = 512;
	while(sectorCount > 0)
	{
        SDReadSingleBlock(sector*blockLength, buffer);
        buffer+= blockLength;
        --sectorCount;
        ++sector;
	}

    return true;

}

#endif // defined NDS
